# hfcldd.spec - hfcldd package for Driver Update Model in RHEL7
#
# Copyright (C) 2014, Hitachi, Ltd.
#
# Based on test.spec by Jon Masters <jcm@redhat.com>
# at http://www.kerneldrivers.org/RedHatKernelModulePackages

# kversion: target kernel version as 'uname -r', e.g., 2.6.18-8.el5xen.
#%{!?kversion: %define kversion %(uname -r)}

# kverrel: kversion where variant suffix (xen and PAE) is removed.
#%{expand:%define kverrel %( shopt -s extglob; foo=%{kversion}; echo ${foo%%%%@(xen|PAE)} )}

# kvariant: variant suffix itself.  Can be an empty string.
#%{expand:%define kvariant %( foo=%{kversion}; echo ${foo#%{kverrel}} )}

# kvar: yields '-' plus kvariant if kvariant is non-null.  Null otherwise.
#%{expand:%define kvar %( _kv=%{kvariant}; echo -n ${_kv:+-$_kv} )}

# kdevel: name of matching kernel-devel package.
#%{expand:%define kdevel kernel%{kvar}-devel-%{_target_cpu}}

# ksrc: kernel source directory, provided by matching kernel-devel package.
#%{expand:%define ksrc %{_usrsrc}/kernels/%{kverrel}%{kvar}-%{_target_cpu}}

ExclusiveArch: i686 x86_64 ia64

Name:       hfcldd
%ifarch ia64
Version: 4.7.18.3006
%else
%ifarch x86_64
Version: 4.7.18.3006
%else
Version: 4.7.18.3006
%endif
%endif
Release: 1%{?dist}
Summary:    RHEL7 Driver for Hitachi Fibre Channel Host Bus Adapter
License:    GPL
Group:      System Environment/Drivers
Source0: %{name}-%{version}.tar.bz2
Source1: %{name}.files
Source2: %{name}.conf
Source3: COPYING
Source4: hfcinst.el7.sh
BuildRoot: %(mktemp -ud %{_tmppath}/%{name}-%{version}-%{release}-XXXXXX)
BuildRequires: %kernel_module_package_buildreqs
%kernel_module_package -f %{SOURCE1} default

%description
RHEL7 hfcldd Driver Update package.

%prep
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT
rm -rf $RPM_BUILD_ROOT/opt/hitachi/drivers/hba
mkdir -p $RPM_BUILD_ROOT/opt/hitachi/drivers/hba

%setup -n hfcldd-%{version}
set -- *
mkdir source
mv "$@" source/
mkdir obj

%build
for flavor in %flavors_to_build; do
rm -rf obj/$flavor
cp -r source obj/$flavor
make -C %{kernel_source $flavor} M=$PWD/obj/$flavor
done

%install
export INSTALL_MOD_PATH=$RPM_BUILD_ROOT
export INSTALL_MOD_DIR=extra/%{name}
for flavor in %flavors_to_build ; do
make -C %{kernel_source $flavor} modules_install \
M=$PWD/obj/$flavor
#Cleanup unnecessary kernel-generated module dependency files.
find $INSTALL_MOD_PATH/lib/modules -iname 'modules.*' -exec rm {} \;
done

install -m 644 -D %{SOURCE2} $RPM_BUILD_ROOT/etc/depmod.d/%{name}.conf
install -m 644 -D %{SOURCE3} $RPM_BUILD_ROOT/opt/hitachi/drivers/hba/COPYING
install -o root -g root %{SOURCE4} $RPM_BUILD_ROOT/opt/hitachi/drivers/hba/hfcinst.el7.sh

# In post, it is better to list modules explicitly.
%post
/opt/hitachi/drivers/hba/hfcinst.el7.sh install
rm -rf /usr/share/dracut/modules.d/10hfcldd
%ifarch x86_64

if [ -e /boot/System.map-`uname -r` ]; then
    /sbin/depmod -aeF /boot/System.map-`uname -r` `uname -r` > /dev/null || :
fi
if [ -f /lib/modules/3.10.0-123.el7.x86_64/extra/hfcldd/hraslog_link.ko.hraslog.rename ]; then
	if [ -x /sbin/weak-modules ]; then
		cat <<EOF | /sbin/weak-modules --no-initramfs --add-modules
/lib/modules/3.10.0-123.el7.x86_64/extra/hfcldd/hraslog_link.ko
/lib/modules/3.10.0-123.el7.x86_64/extra/hfcldd/hfcldd.ko
/lib/modules/3.10.0-123.el7.x86_64/extra/hfcldd/hfcldd_conf.ko
EOF
	fi
	rm /lib/modules/3.10.0-123.el7.x86_64/extra/hfcldd/hraslog_link.ko
	if [ -x /sbin/weak-modules ]; then
		cat <<EOF | /sbin/weak-modules --remove-modules
/lib/modules/3.10.0-123.el7.x86_64/extra/hfcldd/hraslog_link.ko
EOF
	fi
else
	if [ -x /sbin/weak-modules ]; then
		cat <<EOF | /sbin/weak-modules --add-modules
/lib/modules/3.10.0-123.el7.x86_64/extra/hfcldd/hraslog_link.ko
/lib/modules/3.10.0-123.el7.x86_64/extra/hfcldd/hfcldd.ko
/lib/modules/3.10.0-123.el7.x86_64/extra/hfcldd/hfcldd_conf.ko
EOF
	fi
fi
%else
if [ -e /lib/modules/2.6.32-71.el6.i686/extra/hfcldd ]; then
	if [ -e /lib/modules/2.6.32-71.el6.i686/extra/hfcldd/hraslog_link.ko ]; then
		mv /lib/modules/2.6.32-71.el6.i686/extra/hfcldd/hraslog_link.ko /lib/modules/2.6.32-71.el6.i686/extra/hfcldd/hraslog_link.ko.hraslog.rename
		if [ -x /sbin/weak-modules ]; then
			cat <<EOF | /sbin/weak-modules --no-initramfs --remove-modules
/lib/modules/2.6.32-71.el6.i686/extra/hfcldd/hraslog_link.ko
EOF
		fi
	fi
	if [ -e /lib/modules/2.6.32-71.el6.i686/extra/hfcldd/hfcldd.ko ]; then
		mv /lib/modules/2.6.32-71.el6.i686/extra/hfcldd/hfcldd.ko /lib/modules/2.6.32-71.el6.i686/extra/hfcldd/hfcldd.ko.backup
		if [ -x /sbin/weak-modules ]; then
			cat <<EOF | /sbin/weak-modules --no-initramfs --remove-modules
/lib/modules/2.6.32-71.el6.i686/extra/hfcldd/hfcldd.ko
EOF
		fi
	fi
	if [ -e /lib/modules/2.6.32-71.el6.i686/extra/hfcldd/hfcldd_conf.ko ]; then
		mv /lib/modules/2.6.32-71.el6.i686/extra/hfcldd/hfcldd_conf.ko /lib/modules/2.6.32-71.el6.i686/extra/hfcldd/hfcldd_conf.ko.backup
		if [ -x /sbin/weak-modules ]; then
			cat <<EOF | /sbin/weak-modules --no-initramfs --remove-modules
/lib/modules/2.6.32-71.el6.i686/extra/hfcldd/hfcldd_conf.ko
EOF
		fi
	fi
fi

if [ -e /boot/System.map-`uname -r` ]; then
    /sbin/depmod -aeF /boot/System.map-`uname -r` `uname -r` > /dev/null || :
fi
if [ -f /lib/modules/2.6.32-131.0.15.el6.i686/extra/hfcldd/hraslog_link.ko.hraslog.rename ]; then
	if [ -x /sbin/weak-modules ]; then
		cat <<EOF | /sbin/weak-modules --no-initramfs --add-modules
/lib/modules/2.6.32-131.0.15.el6.i686/extra/hfcldd/hraslog_link.ko
/lib/modules/2.6.32-131.0.15.el6.i686/extra/hfcldd/hfcldd.ko
/lib/modules/2.6.32-131.0.15.el6.i686/extra/hfcldd/hfcldd_conf.ko
EOF
	fi
	rm /lib/modules/2.6.32-131.0.15.el6.i686/extra/hfcldd/hraslog_link.ko
	if [ -x /sbin/weak-modules ]; then
		cat <<EOF | /sbin/weak-modules --remove-modules
/lib/modules/2.6.32-131.0.15.el6.i686/extra/hfcldd/hraslog_link.ko
EOF
	fi
else
	if [ -x /sbin/weak-modules ]; then
		cat <<EOF | /sbin/weak-modules --add-modules
/lib/modules/2.6.32-131.0.15.el6.i686/extra/hfcldd/hraslog_link.ko
/lib/modules/2.6.32-131.0.15.el6.i686/extra/hfcldd/hfcldd.ko
/lib/modules/2.6.32-131.0.15.el6.i686/extra/hfcldd/hfcldd_conf.ko
EOF
	fi
fi
%endif

# In preun, it is better to list modules explicitly.
%preun
/opt/hitachi/drivers/hba/hfcinst.el7.sh uninstall

# In postun, it is better to list modules explicitly.
%postun
%ifarch x86_64
if [ -e /boot/System.map-`uname -r` ]; then
    /sbin/depmod -aeF /boot/System.map-`uname -r` `uname -r` &> /dev/null || :
fi
if [ -x /sbin/weak-modules ]; then
   cat <<EOF | /sbin/weak-modules --remove-modules
/lib/modules/3.10.0-123.el7.x86_64/extra/hfcldd/hraslog_link.ko
/lib/modules/3.10.0-123.el7.x86_64/extra/hfcldd/hfcldd.ko
/lib/modules/3.10.0-123.el7.x86_64/extra/hfcldd/hfcldd_conf.ko
EOF
fi
%else
if [ -e /boot/System.map-`uname -r` ]; then
    /sbin/depmod -aeF /boot/System.map-`uname -r` `uname -r` &> /dev/null || :
fi
if [ -x /sbin/weak-modules ]; then
    cat <<EOF | /sbin/weak-modules --remove-modules
/lib/modules/2.6.32-131.0.15.el6.i686/extra/hfcldd/hraslog_link.ko
/lib/modules/2.6.32-131.0.15.el6.i686/extra/hfcldd/hfcldd.ko
/lib/modules/2.6.32-131.0.15.el6.i686/extra/hfcldd/hfcldd_conf.ko
EOF
fi
%endif

# In files, do not list directories if not yours.
%files
%defattr(-,root,root)
%ifarch x86_64
/lib/modules/3.10.0-123.el7.x86_64/extra/%{name}/*.ko
%else
/lib/modules/2.6.32-131.0.15.el6.i686/extra/%{name}/*.ko
%endif
/opt/hitachi/drivers/hba/*

%clean
rm -rf $RPM_BUILD_ROOT

%changelog
* Tue Aug  5 2014 Yoshihiro Toyohara <yoshihiro.toyohara.qs@hitachi.com>
- Revision 4.7.18.3006 support
